*$ CREATE COMSCW.FOR
*COPY COMSCW
*
*=== comscw  ===========================================================*
*
      DOUBLE PRECISION FUNCTION COMSCW ( IJ    , XA    , YA    , ZA    ,
     &                                   MREG  , RULL  , LLO   , ICALL )

      INCLUDE '(DBLPRC)'
      INCLUDE '(DIMPAR)'
      INCLUDE '(IOUNIT)'
      INCLUDE '(TRACKR)'
      INCLUDE '(FLKSTK)'
*
*----------------------------------------------------------------------*
*                                                                      *
*     Copyright (C) 1989-2005      by    Alfredo Ferrari & Paola Sala  *
*     All Rights Reserved.                                             *
*                                                                      *
*                                                                      *
*     New comscw for FLUKA9x-200x                                      *
*                                                                      *
*     !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!     *
*     !!! This is a completely dummy routine for Fluka9x/200x. !!!     *
*     !!! The  name has been kept the same as for older  Fluka !!!     *
*     !!! versions for back-compatibility, even though  Comscw !!!     *
*     !!! is applied only to estimators which didn't exist be- !!!     *
*     !!! fore Fluka89.                                        !!!     *
*     !!! User  developed versions  can be used for  weighting !!!     *
*     !!! density-like quantities at runtime                   !!!     *
*     !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!     *
*                                                                      *
*     Input variables:                                                 *
*                                                                      *
*           Ij = (generalized) particle code                           *
*     Xa,Ya,Za = position                                              *
*         Mreg = region number                                         *
*         Rull = amount to be deposited                                *
*          Llo = particle generation                                   *
*        Icall = call id                                               *
*                                                                      *
*     Output variables:                                                *
*                                                                      *
*       Comscw = factor the scored amount will be multiplied by        *
*       Lsczer = logical flag, if true no amount will be scored        *
*                regardless of Comscw                                  *
*                                                                      *
*     Useful variables (common SCOHLP):                                *
*                                                                      *
*     Energy/Star binnings/scorings (Comscw):                          *
*          ISCRNG = 1 --> Energy density  binning                      *
*          ISCRNG = 2 --> Star   density  binning                      *
*          ISCRNG = 3 --> Residual nuclei scoring                      *
*          ISCRNG = 4 --> Momentum transfer density binning            *
*          JSCRNG = # of the binning                                   *
*                                                                      *
*     Useful variables (common SOUEVT):                                *
*                                                                      *
*          X,Y,Zsoevt(i) = position    of the i_th source particle     *
*          TX,Y,Zsoev(i) = direction   of the i_th source particle     *
*              Wtsoev(i) = weight      of the i_th source particle     *
*              Pmsoev(i) = momentum    of the i_th source particle     *
*              Tksoev(i) = kin. energy of the i_th source particle     *
*              Agsoev(i) = age         of the i_th source particle     *
*              Aksoev(i) = Kaon ampl.  of the i_th source particle     *
*              Ussoev(i) = user var.   of the i_th source particle     *
*              Ijsoev(i) = identity    of the i_th source particle     *
*              Nrsoev(i) = region      of the i_th source particle     *
*              Nlsoev(i) = lattice     of the i_th source particle     *
*                Npsoev  = number of the source particles              *
*                                                                      *
*                                                                      *
*----------------------------------------------------------------------*
*
      INCLUDE '(FLKMAT)'
      INCLUDE '(SCOHLP)'
      INCLUDE '(SOUEVT)'
      double precision enerProton
*
      LSCZER = .FALSE.
      COMSCW = ONEONE
* ======== In order to compute doses ========= *
*     (Medium(n) is the material number of region n
*      Rho(m) is the density of material m)
*     IF ( ISCRNG .EQ. 1 ) COMSCW = ONEONE / RHO (MEDIUM(MREG))

* ======== In order to compute RBE included dose ======== *
      if ( ij .eq. 1 ) then

         enerProton = etrack - 0.93827231 
         write(*,*) iscrng
         if ( iscrng .eq. 1 ) then
            if ( enerProton .lt. 0.1) COMSCW =   12.0
         end if

      end if

      RETURN
*=== End of function Comscw ===========================================*
      END


